@@ -17,35 +17,40 @@
 #include <stdlib.h> // getenv, system
 
 // include files for QT
-#include <qdir.h>
-#include <qapplication.h>
-#include <qdockwindow.h>
-#include <qfileinfo.h>
+#include <QtCore/QDir>
+#include <QtGui/QApplication>
+#include <QtGui/QDockWidget>
+#include <QtCore/QFileInfo>
+#include <QtCore/QFile>
+#include <QtCore/QByteArray>
+#include <QtGui/QCloseEvent>
 
 // include files for KDE
 #include <klocale.h>
 #include <kdebug.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
-#include <kdialogbase.h>
 #include <kfiledialog.h>
 #include <kmenubar.h>
-#include <kpopupmenu.h>
+#include <kmenu.h>
 #include <kstatusbar.h>
 #include <kconfig.h>
-#include <kstdaction.h>
+#include <kstandardaction.h>
 #include <kedittoolbar.h>
-#include <kkeydialog.h>
+#include <kshortcutsdialog.h>
 #include <kurl.h>
 #include <kstandarddirs.h>
+#include <kglobal.h>
+#include <KActionCollection>
 
 // application specific includes
 #include "ksayit.h"
+#include <kconfiggroup.h>
 #include "ksayitviewimpl.h"
 #include "voicesetupdlg.h"
 #include "ksayitsystemtray.h"
-#include "effectstack.h"
-#include "fxpluginhandler.h"
+// #include "effectstack.h"
+// #include "fxpluginhandler.h"
 #include "kttsdlib.h"
 #include "doctreeviewimpl.h"
 #include "ksayitbookmarkhandler.h"
@@ -54,42 +59,46 @@
 #define KSAYITUI "ksayitui.rc"
 #define ID_STATUS_MSG 1
 
-KSayItApp::KSayItApp(QWidget* parent, const char* name, WFlags f,
-    const QCString &objID)
-  : KMainWindow(parent, name, f), DCOPObject(objID)
+KSayItApp::KSayItApp(QWidget* parent, Qt::WFlags f,
+    const QByteArray &objID)
+  : KXmlGuiWindow(parent, f)
 {
     config    = NULL;
     view      = NULL;
     tray      = NULL;
-    es        = NULL;
+    // es        = NULL;
     treeview  = NULL;
     bkManager = NULL;
     bkHandler = NULL;
     bkMenu    = NULL;
-  
-    config=kapp->config();
+    m_currentBookmarkFile.clear();
+
+    config=KGlobal::config();
     m_kttslib = new KTTSDLib(this, "KTTSD-Library", kapp);
-    
+
     initView();
     initStatusBar();
     initActions();
-    initBookmarkManager();
-    
+    initBookmarkManager( i18n("Untitled") );
+
+    createGUI(KSAYITUI);
+    setAutoSaveSettings("MainWindow");
+
     readOptions();
-    
+
     // connect TTS plugin handler to this object
     connect(m_kttslib, SIGNAL(signalFinished()),
             this, SLOT(slotTTSFinished()) );
-    
+
     // only used if library thinks it has to call the preferences dialog.
     // e.g. when it detects a bad configuration.
     connect(m_kttslib, SIGNAL(signalCallPreferences()),
             this, SLOT(slotPreferences()) );
-    
+
     // init Clipboard
     cb = QApplication::clipboard();
     connect(cb, SIGNAL(dataChanged()), this, SLOT(slotClipboardChanged()) );
-    
+
     // create SystemTray object
     tray = new KSayItSystemTray(this, "system_tray");
     connect(tray, SIGNAL(signalCallPreferences()), this, SLOT(slotPreferences()) );
@@ -101,22 +110,22 @@ KSayItApp::KSayItApp(QWidget* parent, const char* name, WFlags f,
     connect(tray, SIGNAL(signalPrevActivated()), this, SLOT(slotPrevSentenceActivated()) );
     tray->show();
     tray->setEnabled(true);
-    
+
     // create the FX plugin handler
-    m_fxpluginhandler = new FXPluginHandler(this, "fxpluginhandler", config);
-    m_fxpluginhandler->searchPlugins();
-    
-    // create object for effectstack  
-    es = new EffectStack(m_fxpluginhandler, config);
-    
+    // pluginhandler = new FXPluginHandler(this, "fxpluginhandler", config);
+    // m_fxpluginhandler->searchPlugins();
+
+    // create object for effectstack
+    // es = new EffectStack(m_fxpluginhandler, config);
+
     // emit signalConfigChanged();
     m_kttslib->reloadConfiguration();
-    m_fxpluginhandler ->readConfiguration();
-    
+    // m_fxpluginhandler ->readConfiguration();
+
     // init docview
     // treeview->clear();
     // treeview->createEmptyDocument();
-    slotClear();  
+    slotClear();
 }
 
 KSayItApp::~KSayItApp()
@@ -124,8 +133,8 @@ KSayItApp::~KSayItApp()
   // delete kapp->mainWidget();
   delete m_kttslib;
   delete tray;
-  delete m_fxpluginhandler;
-  delete es;
+  // delete m_fxpluginhandler;
+  // delete es;
   delete view;
   if (bkHandler)
       delete bkHandler;
@@ -136,19 +145,24 @@ KSayItApp::~KSayItApp()
 void KSayItApp::initActions()
 {
   // Standard-Actions
-  open   = KStdAction::open(this, SLOT(slotFileOpen()), actionCollection());
-  save   = KStdAction::save(this, SLOT(slotFileSave()), actionCollection());
-  saveAs = KStdAction::saveAs(this, SLOT(slotFileSaveAs()), actionCollection());
-  KStdAction::quit(this, SLOT(slotFileQuit()), actionCollection());
-  KStdAction::close(this, SLOT(slotCloseMainWindow()), actionCollection());
-  cut   = KStdAction::cut(view, SLOT(slotCut()), actionCollection());
-  copy  = KStdAction::copy(view, SLOT(slotCopy()), actionCollection());
-  paste = KStdAction::paste(view, SLOT(slotPaste()), actionCollection());
-  preferences = KStdAction::preferences(this, SLOT(slotPreferences()), actionCollection());
-  KStdAction::keyBindings(this, SLOT(slotEditKeys()), actionCollection());
-  KStdAction::configureToolbars(this, SLOT(slotConfigureToolbar()), actionCollection());
-  KStdAction::showToolbar("mainToolBar", actionCollection());
-  statusBarAction = KStdAction::showStatusbar(this, SLOT(slotToggleStatusBar()), actionCollection());
+  open   = KStandardAction::open(this, SLOT(slotFileOpen()), actionCollection());
+  save   = KStandardAction::save(this, SLOT(slotFileSave()), actionCollection());
+  saveAs = KStandardAction::saveAs(this, SLOT(slotFileSaveAs()), actionCollection());
+  KStandardAction::quit(this, SLOT(slotFileQuit()), actionCollection());
+  KStandardAction::close(this, SLOT(slotCloseMainWindow()), actionCollection());
+  cut   = KStandardAction::cut(view, SLOT(slotCut()), actionCollection());
+  copy  = KStandardAction::copy(view, SLOT(slotCopy()), actionCollection());
+  paste = KStandardAction::paste(view, SLOT(slotPaste()), actionCollection());
+  preferences = KStandardAction::preferences(this, SLOT(slotPreferences()), actionCollection());
+  KStandardAction::keyBindings(this, SLOT(slotEditKeys()), actionCollection());
+  KStandardAction::configureToolbars(this, SLOT(slotConfigureToolbar()), actionCollection());
+#ifdef __GNUC__
+#warning "KStandardAction::showToolbar was deprecated"
+#endif
+#if 0
+  KStandardAction::showToolbar("mainToolBar", actionCollection());
+#endif
+  statusBarAction = KStandardAction::showStatusbar(this, SLOT(slotToggleStatusBar()), actionCollection());
 
   // User defined actions
   say = new KAction (i18n("Say"),
@@ -162,44 +176,45 @@ void KSayItApp::initActions()
               this, SLOT (slotPauseActivated()),
               actionCollection(),
               "pause");
-  
+
   shutup = new KAction (i18n("Shut Up"),
               Qt::Key_F10,
               this, SLOT (slotStopActivated()),
               actionCollection(),
               "shut_up");
-              
+
   next_sentence = new KAction (i18n("Next Sentence"),
-              Qt::Key_Next,
+              Qt::Key_PageDown,
               this, SLOT (slotNextSentenceActivated()),
               actionCollection(),
               "next_sentence");
 
 
   prev_sentence = new KAction (i18n("Previous Sentence"),
-              Qt::Key_Prior,
+              Qt::Key_PageUp,
               this, SLOT(slotPrevSentenceActivated()),
               actionCollection(),
               "prev_sentence");
-  
+
   clear = new KAction (i18n("Clear"),
               Qt::Key_F12,
               this, SLOT(slotClear()),
               actionCollection(),
               "clear");
-  
+
   edit = new KToggleAction( i18n("Edit Text"),
              0,
              this, SLOT(slotEditToggled()),
              actionCollection(),
              "edittext");
-             
-  bookmarkmenu = new KActionMenu( i18n("Bookmarks"),
-             "bookmark", // icon
+
+  bookmarkmenu = new KActionMenu(
+             KIcon("bookmarks"), // icon
+             i18n("Bookmarks"),
              actionCollection(),
              "bookmarks"); // name
              bookmarkmenu->setDelayed(false);
-  
+
   // default disable/enable
   save         ->setEnabled(false);
   saveAs       ->setEnabled(false);
@@ -213,77 +228,94 @@ void KSayItApp::initActions()
   prev_sentence->setEnabled(false);
   preferences  ->setEnabled(true);
   edit         ->setChecked(false);
+  bookmarkmenu ->setEnabled(false);
   m_ap_saying = false;
   m_ap_paused = false;
   m_textview_empty = true;
 }
 
 
-void KSayItApp::initBookmarkManager()
+void KSayItApp::initBookmarkManager(const QString &filename)
 {
-    QString bkFile = getBookmarkDir( i18n("Untitled") );
-    if ( !bkFile.isNull() ){    
-        bkManager = KBookmarkManager::managerForFile( bkFile, false );
-        
-        // create BookmarkHandler object
-        bkHandler = new KSayItBookmarkHandler(bkManager, this);
-        
-        // create Bookmarkmenu
-        KPopupMenu *bkPopupMenu = bookmarkmenu->popupMenu(); 
-        bkMenu = new KBookmarkMenu(bkManager, bkHandler, bkPopupMenu, 0, true );
-        
-        connect(treeview, SIGNAL(signalNotifyBookmarkManager(const QString&, const QString&)),
-            this, SLOT(slotNotifyBookmarkHandler(const QString&, const QString&)) );
-        connect(treeview, SIGNAL(signalSetBookmarkFilename(const QString&)),
-            this, SLOT(slotSetBookmarkFilename(const QString&)) );
-    }    
-          
-    createGUI(KSAYITUI);
-    setAutoSaveSettings("MainWindow");   
+    QString bkFile = getBookmarkDir( filename );
+    if ( bkFile.isNull() )
+        return;
+
+    m_currentBookmarkFile = bkFile;
+    bkManager = KBookmarkManager::managerForFile( bkFile, "ksayit" );
+
+    // create BookmarkHandler object
+    if ( bkHandler )
+        delete bkHandler;
+    bkHandler = new KSayItBookmarkHandler(bkManager, this);
+
+    // create Bookmarkmenu
+    KMenu *bkPopupMenu = bookmarkmenu->popupMenu();
+    if ( bkMenu )
+        delete bkMenu;
+    bkMenu = new KBookmarkMenu(bkManager, bkHandler, bkPopupMenu, 0, true );
 }
 
 
 void KSayItApp::slotNotifyBookmarkHandler(const QString &ID, const QString &title)
 {
-    bkHandler->notifyBookmarkHandler(ID, title);
+    if ( bkHandler )
+        bkHandler->notifyBookmarkHandler(ID, title);
 }
 
 
-void KSayItApp::slotSetBookmarkFilename(const QString &filename)
+void KSayItApp::slotDeleteBookmark(const QString &url, const QString &title)
 {
-    QString bkFile = getBookmarkDir( filename );
-    if ( bkFile.isNull() )
-        return;    
-
-    bkManager = KBookmarkManager::managerForFile( bkFile, false );
-    
-    // create BookmarkHandler object
+    kDebug(100200) << "KSayItApp::slotDeleteBookmark(" << url << ")";
     if ( bkHandler )
-        delete bkHandler;
-    bkHandler = new KSayItBookmarkHandler(bkManager, this);
-    bkHandler->setFilename(filename);
-    
-    // create Bookmarkmenu
-    KPopupMenu *bkPopupMenu = bookmarkmenu->popupMenu(); 
-    if (bkMenu)
-        delete bkMenu;
-    bkMenu = new KBookmarkMenu(bkManager, bkHandler, bkPopupMenu, 0, true );
+        bkHandler->deleteBookmark( url, title );
 }
 
 
 QString KSayItApp::getBookmarkDir(const QString &filename)
 {
     QString bkRelPath = "ksayit/ksayit_bookmarks/" + filename + ".bookmarks";
-    QString bkFile;   
-    bkFile = locateLocal("data", bkRelPath);
+    QString bkFile;
+    bkFile = KStandardDirs::locateLocal("data", bkRelPath);
     return bkFile;
 }
 
 
-bool KSayItApp::setItemByBookmark( const QString &ID )
+void KSayItApp::slotSetBookmarkFilename(const QString &newname)
 {
-    bool result;
-    result = treeview->selectItemByID( ID );
+    kDebug(100200) << "KSayItApp::slotSetBookmarkFilename(" << newname << ")";
+
+    initBookmarkManager(newname);
+}
+
+
+void KSayItApp::slotChangeBookmarkFilename(const QString &newname)
+{
+    kDebug(100200) << "KSayItApp::slotChangeBookmarkFilename(" << newname << ")";
+
+    if ( m_currentBookmarkFile.isNull() )
+        return;
+
+    QString newbkFile = getBookmarkDir(newname);
+    if ( newbkFile.isNull() )
+        return;
+
+    // copy old bookmarkfile to new file
+    if ( m_currentBookmarkFile != newbkFile ){
+        if ( QFile::exists(m_currentBookmarkFile) ){
+            QString command = QString("cp %1 %2").arg(m_currentBookmarkFile).arg(newbkFile);
+            system( command.ascii() );
+        }
+        // install new BookmarkHandler based on the new file
+        initBookmarkManager(newname);
+    }
+}
+
+
+QString KSayItApp::setItemByBookmark( const QString &ID, const QString &title )
+{
+    QString result;
+    result = treeview->selectItemByID( ID, title );
     return result;
 }
 
@@ -297,37 +329,51 @@ void KSayItApp::initStatusBar()
 
 
 void KSayItApp::initView()
-{ 
+{
   // create the main widget
   view = new KSayItViewImpl(this);
   view->setMinimumSize(view->sizeHint());
   setCentralWidget(view);
   // connections
-  connect( view, SIGNAL(signalEnableCopyCut(bool)), this, SLOT(slotEnableCopyCut(bool)));
-  connect( view, SIGNAL(signalShowStatus(const QString &)), this, SLOT(slotStatusMsg(const QString &)));
-  connect( view, SIGNAL(signalSetCaption(const QString &)), this, SLOT(slotSetCaption(const QString &)));
-  connect( view, SIGNAL(signalTextChanged(bool)), this, SLOT(slotTextChanged(bool)) );
-  
+  connect( view, SIGNAL(signalEnableCopyCut(bool)),
+    this, SLOT(slotEnableCopyCut(bool)));
+  connect( view, SIGNAL(signalShowStatus(const QString &)),
+    this, SLOT(slotStatusMsg(const QString &)));
+  connect( view, SIGNAL(signalSetCaption(const QString &)),
+    this, SLOT(slotSetCaption(const QString &)));
+  connect( view, SIGNAL(signalTextChanged(bool)),
+    this, SLOT(slotTextChanged(bool)) );
+
   // DockWindow
-  QDockWindow *docview = new QDockWindow(QDockWindow::InDock, this, "docview");
+  QDockWidget *docview = new QDockWidget(this);
   treeview = new DocTreeViewImpl(docview, "treeview");
+  treeview->enableContextMenus( true );
   // treeview->clear();
   docview->setWidget(treeview);
-  docview->setResizeEnabled(true);
-  this->setDockEnabled(docview, Qt::DockTop, false);
-  this->setDockEnabled(docview, Qt::DockBottom, false);
-  this->moveDockWindow(docview, Qt::DockLeft);
-  connect( treeview, SIGNAL(signalContentChanged(const QString&)), this, SLOT(slotTreeViewChanged(const QString&)) );
-  connect( treeview, SIGNAL(signalSetText(const QString&)), this, SLOT(slotSetText(const QString&)) );
-  connect( treeview, SIGNAL(signalAllNodesProcessed()), this, SLOT(slotSayNode()) );
-  connect( treeview, SIGNAL(signalEnableTextedit(bool)), this, SLOT(slotEnableTextedit(bool)) );
-  
+  docview->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::TopDockWidgetArea | Qt::BottomDockWidgetArea);
+  connect( treeview, SIGNAL(signalContentChanged(const QString&)),
+    this, SLOT(slotTreeViewChanged(const QString&)) );
+  connect( treeview, SIGNAL(signalSetText(const QString&)),
+    this, SLOT(slotSetText(const QString&)) );
+  connect( treeview, SIGNAL(signalAllNodesProcessed()),
+    this, SLOT(slotSayNode()) );
+  connect( treeview, SIGNAL(signalEnableTextedit(bool)),
+    this, SLOT(slotEnableTextedit(bool)) );
+  connect( treeview, SIGNAL(signalNotifyBookmarkManager(const QString&, const QString&)),
+    this, SLOT(slotNotifyBookmarkHandler(const QString&, const QString&)) );
+  connect( treeview, SIGNAL(signalSetBookmarkFilename(const QString&)),
+    this, SLOT(slotSetBookmarkFilename(const QString&)) );
+  connect( treeview, SIGNAL(signalChangeBookmarkFilename(const QString&)),
+    this, SLOT(slotChangeBookmarkFilename(const QString&)) );
+  connect( treeview, SIGNAL(signalDeleteBookmark(const QString&, const QString&)),
+    this, SLOT(slotDeleteBookmark(const QString&, const QString&)) );
 }
 
 
 void KSayItApp::readOptions()
 {
-  applyMainWindowSettings( config, "MainWindow" );
+    KConfigGroup grp = config->group( "MainWindow" );
+  applyMainWindowSettings( grp );
   statusBarAction->setChecked(!statusBar()->isHidden());
 }
 
@@ -346,6 +392,7 @@ void KSayItApp::closeEvent(QCloseEvent *ce)
 // DCOP FUNCTIONS
 /////////////////////////////////////////////////////////////////////
 
+/*
 ASYNC KSayItApp::dcopSayText(QString msg)
 {
   slotSetText( msg );
@@ -358,18 +405,18 @@ ASYNC KSayItApp::dcopStop()
 }
 
 
-ASYNC KSayItApp::dcopSayXmlFile(KURL url)
+ASYNC KSayItApp::dcopSayXmlFile(KUrl url)
 {
     slotStatusMsg(i18n("Say XML file..."));
     m_enableChangeNotifications = false;
-   
+
     try{
         if ( !url.isEmpty() ){
-            resetView();    
+            resetView();
             treeview->openFile( url );
             setActions(ACTIONS::PLAY | ACTIONS::FFWD);
             save  ->setEnabled(false);
-            saveAs->setEnabled(true);              
+            saveAs->setEnabled(true);
             edit->setChecked(false);
             treeview->setEditMode( false );
         }
@@ -377,14 +424,14 @@ ASYNC KSayItApp::dcopSayXmlFile(KURL url)
     catch( QString err ){
         KMessageBox::error(this, err);
         save  ->setEnabled(false);
-        saveAs->setEnabled(true);              
+        saveAs->setEnabled(true);
     }
-    
+
     m_enableChangeNotifications = true;
-    
+
     slotSayText();
 }
-
+*/
 
 /////////////////////////////////////////////////////////////////////
 // SLOT IMPLEMENTATION
@@ -404,26 +451,31 @@ void KSayItApp::slotEditToggled()
 
 void KSayItApp::slotSaveOptions()
 {
-  saveMainWindowSettings( config, "MainWindow" );
+    KConfigGroup grp = config->group( "MainWindow" );
+  saveMainWindowSettings( grp );
   config->sync();
 }
 
 
 void KSayItApp::slotConfigureToolbar()
 {
-  saveMainWindowSettings( config, "MainWindow" );
-  KEditToolbar dlg(actionCollection(), KSAYITUI);
+    KConfigGroup grp = config->group( "MainWindow" );
+  saveMainWindowSettings( grp );
+#if 0
+  KEditToolBar dlg(actionCollection(), KSAYITUI);
   connect(&dlg,SIGNAL(newToolbarConfig()),this,SLOT(slotNewToolbarConfig()));
   if (dlg.exec())
   {
      createGUI(KSAYITUI);
   }
+#endif
 }
 
 
 void KSayItApp::slotNewToolbarConfig()
 {
-  applyMainWindowSettings( config, "MainWindow" );
+    KConfigGroup grp = config->group( "MainWindow" );
+  applyMainWindowSettings( grp );
 }
 
 
@@ -431,28 +483,30 @@ void KSayItApp::slotFileOpen()
 {
     slotStatusMsg(i18n("Open file..."));
     m_enableChangeNotifications = false;
-   
+
     // open filerequester
     QString fn;
     QString usershome( getenv("HOME") );
-    KURL url = KFileDialog::getOpenURL(usershome, QString::null, this, i18n("File to Speak") );
-    try{
+    KUrl url = KFileDialog::getOpenUrl(usershome, QString(), this, i18n("File to Speak") );
+//    try{
         if ( !url.isEmpty() ){
-            resetView();    
+            resetView();
             treeview->openFile( url );
             setActions(ACTIONS::PLAY | ACTIONS::FFWD);
             save  ->setEnabled(false);
-            saveAs->setEnabled(true);              
+            saveAs->setEnabled(true);
             edit->setChecked(false);
             treeview->setEditMode( false );
+            bookmarkmenu->setEnabled(true);
         }
-    }
-    catch( QString err ){
-        KMessageBox::error(this, err);
-        save  ->setEnabled(false);
-        saveAs->setEnabled(true);              
-    }
-  
+//    }
+//    catch( QString err ){
+//        KMessageBox::error(this, err);
+//        save  ->setEnabled(false);
+//        saveAs->setEnabled(true);
+//        bookmarkmenu->setEnabled(false);
+//    }
+
   m_enableChangeNotifications = true;
 }
 
@@ -460,34 +514,36 @@ void KSayItApp::slotFileOpen()
 void KSayItApp::slotFileSave()
 {
    slotStatusMsg(i18n("Save file..."));
-   try {
+//   try {
          treeview->saveFile();
          save  ->setEnabled(false);
-         saveAs->setEnabled(true);  
-   }   
-   catch ( QString err )
-   {
-      KMessageBox::error(this, err);
-      save  ->setEnabled(true);
-      saveAs->setEnabled(true);  
-   }
+         saveAs->setEnabled(true);
+//   }
+//   catch ( QString err )
+//   {
+//      KMessageBox::error(this, err);
+//      save  ->setEnabled(false);
+//      saveAs->setEnabled(true);
+//   }
 }
 
 
 void KSayItApp::slotFileSaveAs()
 {
   slotStatusMsg(i18n("Save file as..."));
-   try {
+//   try {
          treeview->saveFileAs();
-         save  ->setEnabled(false);
-         saveAs->setEnabled(true);  
-   }   
-   catch ( QString err )
-   {
-      KMessageBox::error(this, err);
-      save  ->setEnabled(true);
-      saveAs->setEnabled(true);  
-   }
+         save  ->setEnabled(true);
+         saveAs->setEnabled(true);
+         bookmarkmenu->setEnabled(true);
+//   }
+//   catch ( QString err )
+//   {
+//      KMessageBox::error(this, err);
+//      save  ->setEnabled(true);
+//      saveAs->setEnabled(true);
+//      bookmarkmenu->setEnabled(false);
+//   }
 }
 
 
@@ -500,20 +556,20 @@ void KSayItApp::slotEnableCopyCut(bool enable)
 
 void KSayItApp::slotEditKeys()
 {
-  KKeyDialog::configure( actionCollection() ); //, xmlFile());
+  KShortcutsDialog::configure( actionCollection() ); //, xmlFile());
 }
 
 
 void KSayItApp::slotFileQuit()
 {
   slotStatusMsg(i18n("Exiting..."));
-  int really = KMessageBox::questionYesNo( this, i18n("Do you really want to quit?") );
+  int really = KMessageBox::questionYesNo( this, i18n("Do you really want to quit?"), QString(), KStandardGuiItem::quit(), KStandardGuiItem::cancel() );
   if (really == KMessageBox::Yes){
      slotSaveOptions();
      kapp->quit();
   } else {
      slotStatusMsg(i18n("Ready."));
-  }  
+  }
 }
 
 
@@ -538,9 +594,12 @@ void KSayItApp::slotToggleStatusBar()
 
 void KSayItApp::slotStatusMsg(const QString &text)
 {
+#warning "kde4 port";
+#if 0
   // change status message permanently
   statusBar()->clear();
   statusBar()->changeItem(text, ID_STATUS_MSG);
+#endif
 }
 
 
@@ -555,13 +614,13 @@ void KSayItApp::slotPreferences()
   // create Preferences object and open it
   VoiceSetupDlg *prefs = new VoiceSetupDlg(this, "preferences", i18n("Setup"), true,
                       config,
-                      m_fxpluginhandler,
+                      /*m_fxpluginhandler,*/
                       m_kttslib);
 
   if (prefs->exec() == QDialog::Accepted){
     delete prefs;
     m_kttslib->reloadConfiguration();
-    m_fxpluginhandler ->readConfiguration();
+    // m_fxpluginhandler ->readConfiguration();
   } else {
     delete prefs;
   }
@@ -582,37 +641,37 @@ void KSayItApp::slotClipboardChanged()
   } else {
       tray->changeState( StateCLIPEMPTY::Instance() );
       paste->setEnabled(false);
-  }  
+  }
 }
 
 
 void KSayItApp::slotTextChanged(bool empty)
 {
     m_textview_empty = empty;
-    
+
     // do nothing if change notifications from the Textedit are
-    // currently not welcome.     
+    // currently not welcome.
     if ( !m_enableChangeNotifications )
-        return; 
-    
+        return;
+
     // do nothing if say is in progress
     if ( m_ap_saying )
         return;
-        
-    kdDebug(100200) << "KSayItApp::slotTextChanged( " << empty << " )" << endl;
-    
+
+    kDebug(100200) << "KSayItApp::slotTextChanged( " << empty << " )";
+
     // Update actions
     if ( empty ){
-        setActions(0);    
+        setActions(0);
     } else {
         setActions(ACTIONS::PLAY);
     }
-    save  ->setEnabled(!empty);
+    // save  ->setEnabled(!empty);
     saveAs->setEnabled(!empty);
-    
+
     // update TreeView-Item
-    treeview->setNodeContent( view->getText() );    
-    
+    treeview->setNodeContent( view->getText() );
+
 }
 
 
@@ -633,6 +692,7 @@ void KSayItApp::slotClear()
     save  ->setEnabled(false);
     saveAs->setEnabled(false);
     setActions(0);
+    bookmarkmenu->setEnabled(false);
     m_enableChangeNotifications = true;
 }
 
@@ -643,11 +703,11 @@ void KSayItApp::slotSayClipboard()
     slotStatusMsg(i18n("speaking Clipboard..."));
     setActions(ACTIONS::PAUSE | ACTIONS::STOP | ACTIONS::FFWD | ACTIONS::FREV);
     tray->changeState( StateSAY::Instance() );
-    
+
     clip = cb->text();
-    // sayActivated( clip.stripWhiteSpace() );
+    // sayActivated( clip.trimmed() );
     // set text and say it
-    slotSetText( clip.stripWhiteSpace() );
+    slotSetText( clip.trimmed() );
     sayActivated();
 }
 
@@ -657,14 +717,14 @@ void KSayItApp::slotSayText()
     // say Text from text-window
     setActions(ACTIONS::PAUSE | ACTIONS::STOP | ACTIONS::FFWD | ACTIONS::FREV);
     tray->changeState( StateSAY::Instance() );
-    
+
     slotStatusMsg(i18n("synthesizing..."));
 
     if ( m_ap_paused ){
         m_ap_paused = false;
         m_kttslib->resume();
     } else {
-        es->loadEffects();
+        // es->loadEffects();
         treeview->sayActiveNodeAndChilds();
     }
 }
@@ -681,44 +741,44 @@ void KSayItApp::slotSetText(const QString &text)
     // also invoked by the treeview for the each node
     if ( text.isNull() )
         return;
-    
-    // put text on the stack of KTTS     
+
+    // put text on the stack of KTTS
     m_kttslib->setText( text );
 }
 
 void KSayItApp::sayActivated()
-{  
-    kdDebug(100200) << "KSayItApp::sayActivated()" << endl;
-    
+{
+    kDebug(100200) << "KSayItApp::sayActivated()";
+
     preferences->setEnabled(false);
     m_ap_saying = true;
-        
-    try {
+
+//    try {
         m_kttslib->sayText();
-    }
-    catch (QString err){
-        kdDebug(100200) << "Exception catched in KSayItApp::sayActivated()" << endl;
-        KMessageBox::sorry(0, err, i18n("Unable to speak text"));
-        slotFinished();
-    }
+//    }
+//    catch (QString err){
+//        kDebug(100200) << "Exception caught in KSayItApp::sayActivated()";
+//        KMessageBox::sorry(0, err, i18n("Unable to speak text"));
+//        slotFinished();
+//    }
 }
 
 
 void KSayItApp::slotTTSFinished()
 {
-    kdDebug(100200) << "KSayItApp::slotTTSFinished()" << endl;
-    es->unloadEffects();
+    kDebug(100200) << "KSayItApp::slotTTSFinished()";
+    // es->unloadEffects();
     slotFinished();
 }
 
 
 void KSayItApp::slotFinished()
 {
-    kdDebug(100200) << "KSayItApp::slotFinished()" << endl; 
-    
+    kDebug(100200) << "KSayItApp::slotFinished()";
+
     // disable/enable actions
     m_ap_paused = false;
-    
+
     if ( m_textview_empty ){
         setActions(0);
     } else {
@@ -734,14 +794,14 @@ void KSayItApp::slotFinished()
 void KSayItApp::slotStopActivated()
 {
     m_kttslib->stop();
-    // slotFinished();    
+    // slotFinished();
 }
 
 
 void KSayItApp::slotPauseActivated()
 {
-    kdDebug(100200) << "KSayItApp::slotPauseActivated()" << endl;
-    
+    kDebug(100200) << "KSayItApp::slotPauseActivated()";
+
     m_kttslib->pause();
     m_ap_paused = true;
     setActions(ACTIONS::PLAY | ACTIONS::STOP);
@@ -752,14 +812,14 @@ void KSayItApp::slotPauseActivated()
 
 void KSayItApp::slotNextSentenceActivated()
 {
-    kdDebug(100200) << "KSayItApp::slotNextSentenceActivated()" << endl;
+    kDebug(100200) << "KSayItApp::slotNextSentenceActivated()";
     m_kttslib->ffwd();
 }
-    
+
 
 void KSayItApp::slotPrevSentenceActivated()
 {
-    kdDebug(100200) << "KSayItApp::slotPrevSentenceActivated()" << endl;
+    kDebug(100200) << "KSayItApp::slotPrevSentenceActivated()";
     m_kttslib->frev();
 }
 
@@ -767,14 +827,14 @@ void KSayItApp::slotPrevSentenceActivated()
 void KSayItApp::setActions(int actions)
 {
     // ACTIONS::PLAY | ACTIONS::STOP  | ACTIONS::PAUSE | ACTIONS::FFWD | ACTIONS::FREV;
-    
+
     // Get the mask of supported actions from the plugin.
     int mask = m_kttslib->getActions();
-    kdDebug(100200) << QString("KSayItApp:PSA: %1").arg(mask, 0, 2) << endl;
-    
+    kDebug(100200) << QString("KSayItApp:PSA: %1").arg(mask, 0, 2);
+
     // disable actions not supported by the plugin
     int ma = actions & mask;
-    
+
     if (ma & ACTIONS::PLAY){
         say->setEnabled(true);
     } else {
@@ -800,7 +860,7 @@ void KSayItApp::setActions(int actions)
     } else {
         prev_sentence->setEnabled(false);
     }
-    
+
     tray->setActions( say->isEnabled(), pause->isEnabled(), shutup->isEnabled(),
         next_sentence->isEnabled(), prev_sentence->isEnabled() );
 }
@@ -808,11 +868,11 @@ void KSayItApp::setActions(int actions)
 
 void KSayItApp::slotTreeViewChanged(const QString &str)
 {
-    kdDebug(100200) << "KSayItApp::slotTreeViewChanged()" << endl;
-    
+    kDebug(100200) << "KSayItApp::slotTreeViewChanged()";
+
     if ( !m_ap_saying )
         setActions(ACTIONS::PLAY);
-    
+
     m_enableChangeNotifications = false;
     view->textClear();
     view->setText(str);
@@ -822,8 +882,8 @@ void KSayItApp::slotTreeViewChanged(const QString &str)
 
 void KSayItApp::slotEnableTextedit(bool enable)
 {
-    kdDebug(100200) << "KSayItApp::slotEnableTextedit( " << enable << " )" << endl;
-    
+    kDebug(100200) << "KSayItApp::slotEnableTextedit( " << enable << " )";
+
     view->enableTextedit( enable );
 }
 
@@ -841,13 +901,13 @@ void KSayItApp::resetView()
     save  ->setEnabled(false);
     saveAs->setEnabled(false);
     setActions(0);
-    m_enableChangeNotifications = true;    
+    m_enableChangeNotifications = true;
 }
 
 
 void KSayItApp::slotAddBookmark()
 {
-    kdDebug(100200) << "KSayItApp::slotAddBookmark()" << endl;
+    kDebug(100200) << "KSayItApp::slotAddBookmark()";
 
 
 }
@@ -855,9 +915,9 @@ void KSayItApp::slotAddBookmark()
 
 void KSayItApp::slotEditBookmarks()
 {
-    kdDebug(100200) << "KSayItApp::slotEditBookmark()" << endl;
+    kDebug(100200) << "KSayItApp::slotEditBookmark()";
+
 
-    
 }
 
 
