@@ -17,28 +17,22 @@
 
 #ifndef KSAYIT_H
 #define KSAYIT_H
- 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
 
 using namespace std;
 
 // include files for Qt
-#include <qstringlist.h>
-#include <qclipboard.h>
+#include <kxmlguiwindow.h>
+#include <QtCore/QByteArray>
+#include <QtGui/QCloseEvent>
+#include <QtGui/QClipboard>
 
-// include files for KDE 
-#include <kapplication.h>
+// include files for KDE
 #include <kmainwindow.h>
-#include <kaccel.h>
 #include <kaction.h>
-#include <kactionclasses.h>
 #include <kurl.h>
-#include <dcopobject.h>
 #include <kbookmarkmanager.h>
 #include <kbookmarkmenu.h>
-
+#include <KToggleAction>
 // App specific includes
 
 // appended to $HOME
@@ -48,8 +42,8 @@ using namespace std;
 class KSayItViewImpl;
 class DocTreeViewImpl;
 class KSayItSystemTray;
-class FXPluginHandler;
-class EffectStack;
+// class FXPluginHandler;
+// class EffectStack;
 class KTTSDLib;
 class KSayItBookmarkHandler;
 
@@ -65,60 +59,61 @@ class KSayItBookmarkHandler;
   *
   * @author Robert Vogl
   */
-class KSayItApp : public KMainWindow, public DCOPObject
+class KSayItApp : public KXmlGuiWindow
 {
   Q_OBJECT
-  K_DCOP
+//   K_DCOP
 
 public:
     /** construtor of KSayItApp, calls all init functions to create the application.
      */
-    KSayItApp(QWidget* parent=0, const char* name=0, WFlags f=0,
-        const QCString &objID=0);
+    KSayItApp(QWidget* parent=0, Qt::WFlags f=0,
+        const QByteArray &objID=0);
     ~KSayItApp();
 
-k_dcop:
-    /** DCOP interface for say operation
-    \param msg The text to speak.
-     */
-    ASYNC dcopSayText(QString msg);
+// TODO: Replace with DBUS.
+// k_dcop:
+//    /** DCOP interface for say operation
+//    \param msg The text to speak.
+//     */
+//    ASYNC dcopSayText(QString msg);
+//
+//    /** DCOP interface for stop operation
+//     */
+//    ASYNC dcopStop();
+//
+//    /** DCOP interface to say DocBook file
+//     */
+//    ASYNC dcopSayXmlFile(KUrl url);
 
-    /** DCOP interface for stop operation
-     */
-    ASYNC dcopStop();
-    
-    /** DCOP interface to say DocBook file
-     */
-    ASYNC dcopSayXmlFile(KURL url);
-     
 
 signals:
     /** emitted when the Configuration was modified
      */
     void signalConfigChanged();
-  
+
 private slots:
     /** Puts the given text on the Job-Stack of KTTSD.
      * \param text The text to say.
      */
     void slotSetText(const QString &text);
-    
+
     /** Called from the ListView widget after one or many
      * 'setText'-Calls. Starts to say the text.
      */
-    void slotSayNode(); 
-    
+    void slotSayNode();
+
     /** Called when a node in the treeview was clicked and
      * new content in the edit window must be shown.
      * \str The new content of the EditView.
-     */    
+     */
     void slotTreeViewChanged(const QString &str);
-    
+
     /** save general Options like all bar positions and status as well as the geometry to
      * the configuration file.
      */
     void slotSaveOptions();
-    
+
     /** closes the windows , then quits the application.
      */
     void slotFileQuit();
@@ -148,15 +143,15 @@ private slots:
     /** activated if "pause" was clicked.
      */
     void slotPauseActivated();
-    
+
     /** activated if "next sentence" was clicked.
      */
     void slotNextSentenceActivated();
-    
+
     /** activated if "previous sentence" was clicked.
      */
     void slotPrevSentenceActivated();
-    
+
     /** called if text processing was finished.
      */
     void slotFinished();
@@ -173,12 +168,12 @@ private slots:
      * \param empty True if the TextEdit view is empty.
      */
     void slotTextChanged(bool empty);
-    
+
     /** enabled/disables the textedit window;
      * \param enable true=enabled, false=disabled
      */
     void slotEnableTextedit(bool enable);
-    
+
     /** toggles the statusbar
      */
     void slotToggleStatusBar();
@@ -190,25 +185,25 @@ private slots:
     /** Called to add a bookmark.
      */
     void slotAddBookmark();
-    
+
     /** Called to delete a bookmark
      */
     void slotDeleteBookmark(const QString &url, const QString &title);
-    
+
     /** Called to edit bookmarks.
      */
     void slotEditBookmarks();
-    
+
     /** Called from slotConfigureToolbar() if we have a new ToolBar-configuration.
      */
     void slotNewToolbarConfig();
-    
+
     /** called whenever the content of the clipboard changes.
      *  Checks if the content of the Clipboard is of type text/plain.
      *  Disables and enables the SystemTray-object.
      */
     void slotClipboardChanged();
-    
+
     /** Deletes the content of the Textview.
      */
     void slotClear();
@@ -232,44 +227,44 @@ private slots:
     /** Save file as
      */
     void slotFileSaveAs();
-    
+
     /** Called, when the TTS Library has finished processing.
      */
     void slotTTSFinished();
-    
+
     /** Edit mode switched on/off.
      */
     void slotEditToggled();
-    
+
     /**
      * Catches the signal from the TreeView object
      * and forwards it to the BookmarkHandler object.
      */
     void slotNotifyBookmarkHandler(const QString &ID, const QString &title);
-        
+
     /**
      * Copies the content of the current bookmark file to the
      * file designated by \p newname and install a new
      * BookmarkHandler.
      * \param newname The name of the new bookmark file.
      */
-    void slotChangeBookmarkFilename(const QString &newname);    
+    void slotChangeBookmarkFilename(const QString &newname);
 
     /** Loads bookmark file corresponding to the given file.
      * \param newname The name of the new file.
      */
-    void slotSetBookmarkFilename(const QString &newname);    
+    void slotSetBookmarkFilename(const QString &newname);
 
-public:   
+public:
     /**
      * Selects the item with the given ID in the TreeView.
      * \param ID The ID of the item to select.
      * \param title The title of the bookmark.
-     * \returns <tt>QString::null</tt>, if the operation was successfull,
+     * \returns <tt>QString()</tt>, if the operation was successful,
      * an error message, if the ID was not found.
      */
     QString setItemByBookmark( const QString &ID, const QString &title );
-    
+
 private: // Methods
     /** read general Options again and initialize all variables.
      */
@@ -285,11 +280,11 @@ private: // Methods
     /**
      */
     void initBookmarkManager(const QString &filename);
-    
+
     /** creates the centerwidget of the KTMainWindow instance and sets it as the view.
      */
     void initView();
-    
+
     /** resets the editor. Do not create an empty document.
      */
     void resetView();
@@ -301,13 +296,13 @@ private: // Methods
     /** reimplemented from baseclass
      */
     virtual void closeEvent(QCloseEvent *ce);
-    
+
     /** disable/enable Actions.
      * \param actions An OR'ed integer of enum ACTIONS. A '1' is supposed
      * as 'Action enabled'.
      */
     void setActions(int actions);
-    
+
     /**
      * Returns the absolute pathname of the given bookmarkfile.
      * This is the first KDE resource directory \p (share/apps) in which
@@ -315,16 +310,16 @@ private: // Methods
      * \p ksayit/ksayit_bookmarks/.
      * \param filename The name of the bookmark file.
      * \returns The absolute pathname of the given bookmark file.
-     * Returns \p QString::null if the operation was not successfull.
+     * Returns \p QString() if the operation was not successful.
      */
     QString getBookmarkDir(const QString &filename);
-    
-    
+
+
 private:
-    KConfig *config;
+    KSharedConfigPtr config;
     KSayItViewImpl *view;
     KSayItSystemTray *tray;
-    EffectStack *es;
+    // EffectStack *es;
     DocTreeViewImpl *treeview;
     KBookmarkManager *bkManager;
     KSayItBookmarkHandler *bkHandler;
@@ -347,12 +342,12 @@ private:
     KAction *preferences;
     KToggleAction *edit;
     KActionMenu *bookmarkmenu;
-    
+
     // Misc stuff
     QClipboard *cb;
     QString clip;
     KTTSDLib *m_kttslib;
-    FXPluginHandler *m_fxpluginhandler;
+    // FXPluginHandler *m_fxpluginhandler;
     bool m_ap_saying;
     bool m_ap_paused;
     bool m_textview_empty;
@@ -360,5 +355,5 @@ private:
     QString m_currentBookmarkFile;
 
 };
- 
+
 #endif // KSAYIT_H
