@@ -49,9 +49,7 @@
 
 int main (int argc, char *argv[])
 {
-    KGlobal::locale()->setMainCatalog("kttsd");
-
-    KAboutData aboutdata("kttsmgr", 0, ki18n("KTTSMgr"),
+    KAboutData aboutdata("kttsmgr", "kttsd", ki18n("KTTSMgr"),
         "0.4.0", ki18n("Text-to-Speech Manager"),
         KAboutData::License_GPL, ki18n("(C) 2002, José Pablo Ezequiel Fernández"));
     aboutdata.addAuthor(ki18n("José Pablo Ezequiel Fernández"),ki18n("Original Author"),"pupeno@pupeno.com");
