@@ -21,13 +21,13 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
-#ifndef _FESTIVALINTPROC_H_
-#define _FESTIVALINTPROC_H_
+#ifndef FESTIVALINTPROC_H
+#define FESTIVALINTPROC_H
 
-#include <qstringlist.h>
-#include <qmutex.h>
+#include <QtCore/QMutex>
+#include <QtCore/QStringList>
 
-#include <kprocess.h>
+#include <k3process.h>
 
 #include <pluginproc.h>
 
@@ -46,7 +46,7 @@ class FestivalIntProc : public PlugInProc{
         /**
          * Constructor
          */
-        FestivalIntProc( QObject* parent = 0, const char* name = 0, const QStringList &args = QStringList());
+        explicit FestivalIntProc( QObject* parent = 0, const QStringList &args = QStringList());
 
         /**
          * Destructor
@@ -211,10 +211,10 @@ class FestivalIntProc : public PlugInProc{
         void queryVoicesFinished(const QStringList &voiceCodes);
 
     private slots:
-        void slotProcessExited(KProcess* proc);
-        void slotReceivedStdout(KProcess* proc, char* buffer, int buflen);
-        void slotReceivedStderr(KProcess* proc, char* buffer, int buflen);
-        void slotWroteStdin(KProcess* proc);
+        void slotProcessExited(K3Process* proc);
+        void slotReceivedStdout(K3Process* proc, char* buffer, int buflen);
+        void slotReceivedStderr(K3Process* proc, char* buffer, int buflen);
+        void slotWroteStdin(K3Process* proc);
 
     private:
         /**
@@ -265,7 +265,7 @@ class FestivalIntProc : public PlugInProc{
         QString m_voiceCode;
 
         /**
-        * True if the voice is preloaded.  Also used as a flag to supress killing
+        * True if the voice is preloaded.  Also used as a flag to suppress killing
         * Festival, since startup time will be excessive.
         */
         bool m_preload;
@@ -303,7 +303,7 @@ class FestivalIntProc : public PlugInProc{
         /**
          * Festival process
          */
-        KProcess* m_festProc;
+        K3Process* m_festProc;
 
         /**
         * Synthesis filename.
@@ -358,4 +358,4 @@ class FestivalIntProc : public PlugInProc{
         SupportsSSML m_supportsSSML;
 };
 
-#endif // _FESTIVALINTPROC_H_
+#endif // FESTIVALINTPROC_H
